@@ -72,14 +72,15 @@ void RootedTreeStructure::importStructure(DataStructurePtr other)
     QQueue<DataPtr> queue; // list of unprocessed data elements
     QHash <Data*, DataPtr> fromOtherToNew; // mapping from old to new data elements
 
-    foreach(DataPtr dataOther, other->dataList()){
+    //FIXME only default data type considered
+    foreach(DataPtr dataOther, other->dataList(0)){
         if (visited.contains(dataOther.get())) {
             continue;
         }
         queue.enqueue(dataOther);
 
         // add data element to tree and register mapping
-        DataPtr dataTree = addData(dataOther->property("name").toString(), 0);
+        DataPtr dataTree = createData(dataOther->property("name").toString(), 0);
         dataTree->setColor(dataOther->color());
         dataTree->setProperty("value", dataOther->property("value").toString());
         dataTree->setX(dataOther->x());
@@ -107,7 +108,7 @@ void RootedTreeStructure::importStructure(DataStructurePtr other)
                 if (!visited.contains(adjacentData.get())){
                     visited.insert(adjacentData.get());
                     queue.enqueue(adjacentData);
-                    DataPtr childdata = addData(adjacentData->property("name").toString(), 0);
+                    DataPtr childdata = createData(adjacentData->property("name").toString(), 0);
                     childdata->setColor(adjacentData->color());
                     childdata->setProperty("value", adjacentData->property("value").toString());
                     childdata->setX(adjacentData->x());
@@ -136,16 +137,16 @@ RootedTreeStructure::~RootedTreeStructure()
 
 QScriptValue RootedTreeStructure::add_data(const QString& name)
 {
-    DataPtr n = addData(name, 0);
+    DataPtr n = createData(name, 0);
     n->setEngine(engine());
     return n->scriptValue();
 }
 
 
 ///FIXME addeding multiple pointers.
-PointerPtr RootedTreeStructure::addPointer(DataPtr from, DataPtr to, int dataType)
+PointerPtr RootedTreeStructure::createPointer(DataPtr from, DataPtr to, int dataType)
 {
-    PointerPtr ptr = DataStructure::addPointer(from, to, dataType);
+    PointerPtr ptr = DataStructure::createPointer(from, to, dataType);
     if (ptr && from->property("ClickPosition").isValid()){
         QPointF pos = from->property("ClickPosition").toPointF();
         const qreal pointersSize = property("PointersRegion").toReal();
@@ -195,13 +196,13 @@ PointerPtr RootedTreeStructure::addPointer(DataPtr from, DataPtr to, int dataTyp
     return ptr;
 }
 
-DataPtr RootedTreeStructure::addData(const QString& name, int dataType)
+DataPtr RootedTreeStructure::createData(const QString& name, int dataType)
 {
     Q_ASSERT(document()->dataTypeList().contains(dataType));
     boost::shared_ptr<RootedTreeNode> n = boost::static_pointer_cast<RootedTreeNode>(
         RootedTreeNode::create(getDataStructure(), generateUniqueIdentifier(), dataType) );
     n->setProperty("name", name);
-    addData(n, dataType);
+    addData(n);
     return n;
 }
 
